==> tencentcloud-sdk-java-3.1.209-sources.jar: com/tencentcloudapi/cis/v20180408/models/DescribeContainerInstancesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cis.v20180408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeContainerInstancesResponse extends AbstractModel{

    /**
    * 容器实例列表
    */
    @SerializedName("ContainerInstanceList")
    @Expose
    private ContainerInstance [] ContainerInstanceList;

    /**
    * 容器实例总数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 容器实例列表 
     * @return ContainerInstanceList 容器实例列表
     */
    public ContainerInstance [] getContainerInstanceList() {
        return this.ContainerInstanceList;
    }

    /**
     * Set 容器实例列表
     * @param ContainerInstanceList 容器实例列表
     */
    public void setContainerInstanceList(ContainerInstance [] ContainerInstanceList) {
        this.ContainerInstanceList = ContainerInstanceList;
    }

    /**
     * Get 容器实例总数 
     * @return TotalCount 容器实例总数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 容器实例总数
     * @param TotalCount 容器实例总数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。 
     * @return RequestId 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
     * @param RequestId 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "ContainerInstanceList.", this.ContainerInstanceList);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/cis/v20180408/models/DescribeContainerInstancesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cis.v20180408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeContainerInstancesResponse extends AbstractModel{

    /**
    * 容器实例列表
    */
    @SerializedName("ContainerInstanceList")
    @Expose
    private ContainerInstance [] ContainerInstanceList;

    /**
    * 容器实例总数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 容器实例列表 
     * @return ContainerInstanceList 容器实例列表
     */
    public ContainerInstance [] getContainerInstanceList() {
        return this.ContainerInstanceList;
    }

    /**
     * Set 容器实例列表
     * @param ContainerInstanceList 容器实例列表
     */
    public void setContainerInstanceList(ContainerInstance [] ContainerInstanceList) {
        this.ContainerInstanceList = ContainerInstanceList;
    }

    /**
     * Get 容器实例总数 
     * @return TotalCount 容器实例总数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 容器实例总数
     * @param TotalCount 容器实例总数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。 
     * @return RequestId 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
     * @param RequestId 唯一请求ID，每次请求都会返回。定位问题时需要提供该次请求的RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeContainerInstancesResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeContainerInstancesResponse(DescribeContainerInstancesResponse source) {
        if (source.ContainerInstanceList != null) {
            this.ContainerInstanceList = new ContainerInstance[source.ContainerInstanceList.length];
            for (int i = 0; i < source.ContainerInstanceList.length; i++) {
                this.ContainerInstanceList[i] = new ContainerInstance(source.ContainerInstanceList[i]);
            }
        }
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "ContainerInstanceList.", this.ContainerInstanceList);
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
